@@ -22,26 +22,25 @@
 #define _LIBNFS_H_
 
 #include <stdint.h>
-#if defined(ANDROID)
+#if defined(__ANDROID__) || defined(AROS) \
+ || ( defined(__APPLE__) && defined(__MACH__) )
 #include <sys/time.h>
-#endif
-#if defined(AROS)
-#include <sys/time.h>
-#endif
-#if defined(__APPLE__) && defined(__MACH__)
-#include <sys/time.h>
-#endif
-#if defined(__OpenBSD__)
-#include <sys/time.h> /* gettimeofday */
+#else
+#include <time.h>
 #endif
 
 #ifdef __cplusplus
 extern "C" {
 #endif
+#if defined(__OpenBSD__)
+#include <sys/time.h> /* gettimeofday */
+#endif
 
 #define LIBNFS_FEATURE_READAHEAD
+#define LIBNFS_FEATURE_PAGECACHE
 #define LIBNFS_FEATURE_DEBUG
 #define NFS_BLKSIZE 4096
+#define NFS_PAGECACHE_DEFAULT_TTL 5
 
 struct nfs_context;
 struct rpc_context;
@@ -58,7 +57,10 @@ struct nfs_url {
 #define EXTERN
 #endif
 
-#if defined(WIN32)
+#ifdef WIN32
+#ifdef HAVE_FUSE_H
+#include <fuse.h>
+#else
 struct statvfs {
 	uint32_t	f_bsize;
 	uint32_t	f_frsize;
@@ -72,21 +74,47 @@ struct statvfs {
 	uint32_t	f_flag;
 	uint32_t	f_namemax;
 };
+#endif
+#if !defined(__MINGW32__)
 struct utimbuf {
 	time_t actime;
 	time_t modtime;
 };
+#endif
 #define R_OK	4
 #define W_OK	2
 #define X_OK	1
 #endif
 
 /*
- * Used for interfacing the async version of the api into an external eventsystem
+ * Used for interfacing the async version of the api into an external
+ * eventsystem.
+ *
+ * nfs_get_fd() returns the file descriptor for the context we need to
+ * listen for events from.
+ *
+ * nfs_which_events() returns which events that we need to poll for.
+ * This is a combination of the POLLIN and POLLOUT flags.
+ *
+ * nfs_service() This function should be called once there are events triggered
+ * for the filedescriptor. This function takes POLLIN/POLLOUT/POLLHUP/POLLERR
+ * as arguments.
+ * This function returns 0 on success or -1 on error. If it returns -1 it
+ * means that the socket is in an unrecoverable error state (disconnected?)
+ * and that no further commands can be used.
+ * When this happens the application should destroy the now errored context
+ * re-create a new context and reconnect.
+ *
  */
 EXTERN int nfs_get_fd(struct nfs_context *nfs);
 EXTERN int nfs_which_events(struct nfs_context *nfs);
 EXTERN int nfs_service(struct nfs_context *nfs, int revents);
+
+/*
+ * Returns the number of commands in-flight. Can be used by the application
+ * to check if there are any more responses we are awaiting for the server
+ * or if the connection is completely idle.
+ */
 EXTERN int nfs_queue_length(struct nfs_context *nfs);
 
 /*
@@ -95,6 +123,12 @@ EXTERN int nfs_queue_length(struct nfs_context *nfs);
 struct AUTH;
 EXTERN void nfs_set_auth(struct nfs_context *nfs, struct AUTH *auth);
 
+/*
+ * Used if you need to bind to a specific interface.
+ * Only available on platforms that support SO_BINDTODEVICE.
+ */
+EXTERN void nfs_set_interface(struct nfs_context *nfs, const char *ifname);
+
 /*
  * When an operation failed, this function can extract a detailed error string.
  */
@@ -117,7 +151,7 @@ typedef void (*rpc_cb)(struct rpc_context *rpc, int status, void *data, void *pr
  * NFS CONTEXT.
  */
 /*
- * Create an NFS c, the context.
+ * Create an NFS context.
  * Function returns
  *  NULL : Failed to create a context.
  *  *nfs : A pointer to an nfs context.
@@ -139,15 +173,28 @@ EXTERN void nfs_destroy_context(struct nfs_context *nfs);
  * the nfs context to reflect settings controlled via url arguments.
  *
  * Current URL arguments are :
- * tcp-syncnt=<int>  : Number of SYNs to send during the seccion establish
- *                     before failing settin up the tcp connection to the
+ * tcp-syncnt=<int>  : Number of SYNs to send during the session establish
+ *                     before failing setting up the TCP connection to the
  *                     server.
  * uid=<int>         : UID value to use when talking to the server.
- *                     default it 65534 on Windows and getuid() on unixen.
+ *                     default is 65534 on Windows and getuid() on unixen.
  * gid=<int>         : GID value to use when talking to the server.
- *                     default it 65534 on Windows and getgid() on unixen.
+ *                     default is 65534 on Windows and getgid() on unixen.
  * readahead=<int>   : Enable readahead for files and set the maximum amount
- *                     of readahead to <int>.
+ *                     of readahead to <int> bytes.
+ * auto-traverse-mounts=<0|1>
+ *                   : Should libnfs try to traverse across nested mounts
+ *                     automatically or not. Default is 1 == enabled.
+ * dircache=<0|1>    : Disable/enable directory caching. Enabled by default.
+ * autoreconnect=<-1|0|>=1>
+ *                   : Control the auto-reconnect behaviour to the NFS session.
+ *                    -1 : Try to reconnect forever on session failures.
+ *                         Just like normal NFS clients do.
+ *                     0 : Disable auto-reconnect completely and immediately
+ *                         return a failure to the application.
+ *                   >=1 : Retry to connect back to the server this many
+ *                         times before failing and returing an error back
+ *                         to the application.
  */
 /*
  * Parse a complete NFS URL including, server, path and
@@ -187,14 +234,23 @@ EXTERN uint64_t nfs_get_readmax(struct nfs_context *nfs);
 EXTERN uint64_t nfs_get_writemax(struct nfs_context *nfs);
 
 /*
- *  MODIFY CONNECT PARAMTERS
+ *  MODIFY CONNECT PARAMETERS
  */
 
 EXTERN void nfs_set_tcp_syncnt(struct nfs_context *nfs, int v);
 EXTERN void nfs_set_uid(struct nfs_context *nfs, int uid);
 EXTERN void nfs_set_gid(struct nfs_context *nfs, int gid);
+EXTERN void nfs_set_pagecache(struct nfs_context *nfs, uint32_t v);
+EXTERN void nfs_set_pagecache_ttl(struct nfs_context *nfs, uint32_t v);
 EXTERN void nfs_set_readahead(struct nfs_context *nfs, uint32_t v);
 EXTERN void nfs_set_debug(struct nfs_context *nfs, int level);
+EXTERN void nfs_set_dircache(struct nfs_context *nfs, int enabled);
+EXTERN void nfs_set_autoreconnect(struct nfs_context *nfs, int num_retries);
+
+/*
+ *  Invalidate the pagecache
+ */
+EXTERN void nfs_pagecache_invalidate(struct nfs_context *nfs, struct nfsfh *nfsfh);
 
 /*
  * MOUNT THE EXPORT
@@ -215,7 +271,7 @@ EXTERN int nfs_mount_async(struct nfs_context *nfs, const char *server, const ch
 /*
  * Sync nfs mount.
  * Function returns
- *      0 : The operation was successfull.
+ *      0 : The operation was successful.
  * -errno : The command failed.
  */
 EXTERN int nfs_mount(struct nfs_context *nfs, const char *server, const char *exportname);
@@ -244,7 +300,7 @@ EXTERN int nfs_stat_async(struct nfs_context *nfs, const char *path, nfs_cb cb,
 /*
  * Sync stat(<filename>)
  * Function returns
- *      0 : The operation was successfull.
+ *      0 : The operation was successful.
  * -errno : The command failed.
  */
 /* This function is deprecated. Use nfs_stat64() instead */
@@ -299,7 +355,7 @@ EXTERN int nfs_stat64_async(struct nfs_context *nfs, const char *path, nfs_cb cb
 /*
  * Sync stat(<filename>)
  * Function returns
- *      0 : The operation was successfull.
+ *      0 : The operation was successful.
  * -errno : The command failed.
  */
 EXTERN int nfs_stat64(struct nfs_context *nfs, const char *path, struct nfs_stat_64 *st);
@@ -328,7 +384,7 @@ EXTERN int nfs_lstat64_async(struct nfs_context *nfs, const char *path, nfs_cb c
  * symbolic link itself.
  *
  * Function returns
- *      0 : The operation was successfull.
+ *      0 : The operation was successful.
  * -errno : The command failed.
  */
 EXTERN int nfs_lstat64(struct nfs_context *nfs, const char *path, struct nfs_stat_64 *st);
@@ -353,7 +409,7 @@ EXTERN int nfs_fstat_async(struct nfs_context *nfs, struct nfsfh *nfsfh, nfs_cb
 /*
  * Sync fstat(nfsfh *)
  * Function returns
- *      0 : The operation was successfull.
+ *      0 : The operation was successful.
  * -errno : The command failed.
  */
 #ifdef WIN32
@@ -386,7 +442,7 @@ EXTERN int nfs_fstat64_async(struct nfs_context *nfs, struct nfsfh *nfsfh, nfs_c
 /*
  * Sync fstat(nfsfh *)
  * Function returns
- *      0 : The operation was successfull.
+ *      0 : The operation was successful.
  * -errno : The command failed.
  */
 EXTERN int nfs_fstat64(struct nfs_context *nfs, struct nfsfh *nfsfh, struct nfs_stat_64 *st);
@@ -407,13 +463,14 @@ EXTERN uint16_t nfs_umask(struct nfs_context *nfs, uint16_t mask);
  * Async open(<filename>)
  *
  * mode is a combination of the flags :
- * O_RDOLNY, O_WRONLY, O_RDWR , O_SYNC, O_APPEND, O_TRUNC
+ * O_RDONLY, O_WRONLY, O_RDWR , O_SYNC, O_APPEND, O_TRUNC, O_NOFOLLOW
  *
  * Function returns
  *  0 : The operation was initiated. Once the operation finishes, the callback will be invoked.
  * <0 : An error occured when trying to set up the operation. The callback will not be invoked.
  *
  * Supported flags are
+ * O_NOFOLLOW
  * O_APPEND
  * O_RDONLY
  * O_WRONLY
@@ -432,7 +489,7 @@ EXTERN int nfs_open_async(struct nfs_context *nfs, const char *path, int flags,
 /*
  * Sync open(<filename>)
  * Function returns
- *      0 : The operation was successfull. *nfsfh is filled in.
+ *      0 : The operation was successful. *nfsfh is filled in.
  * -errno : The command failed.
  */
 EXTERN int nfs_open(struct nfs_context *nfs, const char *path, int flags, struct nfsfh **nfsfh);
@@ -460,7 +517,7 @@ EXTERN int nfs_close_async(struct nfs_context *nfs, struct nfsfh *nfsfh, nfs_cb
 /*
  * Sync close(nfsfh)
  * Function returns
- *      0 : The operation was successfull.
+ *      0 : The operation was successful.
  * -errno : The command failed.
  */
 EXTERN int nfs_close(struct nfs_context *nfs, struct nfsfh *nfsfh);
@@ -490,7 +547,7 @@ EXTERN int nfs_pread_async(struct nfs_context *nfs, struct nfsfh *nfsfh, uint64_
  *    >=0 : numer of bytes read.
  * -errno : An error occured.
  */
-EXTERN int nfs_pread(struct nfs_context *nfs, struct nfsfh *nfsfh, uint64_t offset, uint64_t count, char *buf);
+EXTERN int nfs_pread(struct nfs_context *nfs, struct nfsfh *nfsfh, uint64_t offset, uint64_t count, void *buf);
 
 
 
@@ -518,7 +575,7 @@ EXTERN int nfs_read_async(struct nfs_context *nfs, struct nfsfh *nfsfh, uint64_t
  *    >=0 : numer of bytes read.
  * -errno : An error occured.
  */
-EXTERN int nfs_read(struct nfs_context *nfs, struct nfsfh *nfsfh, uint64_t count, char *buf);
+EXTERN int nfs_read(struct nfs_context *nfs, struct nfsfh *nfsfh, uint64_t count, void *buf);
 
 
 
@@ -539,14 +596,14 @@ EXTERN int nfs_read(struct nfs_context *nfs, struct nfsfh *nfsfh, uint64_t count
  * -errno : An error occured.
  *          data is the error string.
  */
-EXTERN int nfs_pwrite_async(struct nfs_context *nfs, struct nfsfh *nfsfh, uint64_t offset, uint64_t count, char *buf, nfs_cb cb, void *private_data);
+EXTERN int nfs_pwrite_async(struct nfs_context *nfs, struct nfsfh *nfsfh, uint64_t offset, uint64_t count, const void *buf, nfs_cb cb, void *private_data);
 /*
  * Sync pwrite()
  * Function returns
  *    >=0 : numer of bytes written.
  * -errno : An error occured.
  */
-EXTERN int nfs_pwrite(struct nfs_context *nfs, struct nfsfh *nfsfh, uint64_t offset, uint64_t count, char *buf);
+EXTERN int nfs_pwrite(struct nfs_context *nfs, struct nfsfh *nfsfh, uint64_t offset, uint64_t count, const void *buf);
 
 
 /*
@@ -565,14 +622,14 @@ EXTERN int nfs_pwrite(struct nfs_context *nfs, struct nfsfh *nfsfh, uint64_t off
  * -errno : An error occured.
  *          data is the error string.
  */
-EXTERN int nfs_write_async(struct nfs_context *nfs, struct nfsfh *nfsfh, uint64_t count, char *buf, nfs_cb cb, void *private_data);
+EXTERN int nfs_write_async(struct nfs_context *nfs, struct nfsfh *nfsfh, uint64_t count, const void *buf, nfs_cb cb, void *private_data);
 /*
  * Sync write()
  * Function returns
  *    >=0 : numer of bytes written.
  * -errno : An error occured.
  */
-EXTERN int nfs_write(struct nfs_context *nfs, struct nfsfh *nfsfh, uint64_t count, char *buf);
+EXTERN int nfs_write(struct nfs_context *nfs, struct nfsfh *nfsfh, uint64_t count, const void *buf);
 
 
 /*
@@ -706,6 +763,27 @@ EXTERN int nfs_mkdir_async(struct nfs_context *nfs, const char *path, nfs_cb cb,
  */
 EXTERN int nfs_mkdir(struct nfs_context *nfs, const char *path);
 
+/*
+ * Async mkdir2()
+ *
+ * Function returns
+ *  0 : The operation was initiated. Once the operation finishes, the callback will be invoked.
+ * <0 : An error occured when trying to set up the operation. The callback will not be invoked.
+ *
+ * When the callback is invoked, status indicates the result:
+ *      0 : Success.
+ * -errno : An error occured.
+ *          data is the error string.
+ */
+EXTERN int nfs_mkdir2_async(struct nfs_context *nfs, const char *path, int mode, nfs_cb cb, void *private_data);
+/*
+ * Sync mkdir2()
+ * Function returns
+ *      0 : Success
+ * -errno : An error occured.
+ */
+EXTERN int nfs_mkdir2(struct nfs_context *nfs, const char *path, int mode);
+
 
 
 /*
@@ -764,6 +842,7 @@ EXTERN int nfs_creat(struct nfs_context *nfs, const char *path, int mode, struct
  * Async create()
  *
  * Same as nfs_creat_async but allows passing flags:
+ * O_NOFOLLOW
  * O_APPEND
  * O_SYNC
  * O_EXCL
@@ -907,6 +986,36 @@ struct nfsdirent  {
 EXTERN struct nfsdirent *nfs_readdir(struct nfs_context *nfs, struct nfsdir *nfsdir);
 
 
+/*
+ * SEEKDIR()
+ */
+/*
+ * This function will never block so there is no need for an async version.
+ */
+EXTERN void nfs_seekdir(struct nfs_context *nfs, struct nfsdir *nfsdir,
+                        long loc);
+
+/*
+ * TELLDIR()
+ */
+/*
+ * On success, nfs_telldir() will return a location as a value >= 0.
+ * On failure, nfs_telldir() will return -1.
+ *
+ * This function will never block so there is no need for an async version.
+ */
+EXTERN long nfs_telldir(struct nfs_context *nfs, struct nfsdir *nfsdir);
+
+
+/*
+ * REWINDDIR()
+ */
+/*
+ * nfs_rewinddir() cancel all previous nfs_readdir() side effects.
+ * This function will never block so there is no need for an async version.
+ */
+EXTERN void nfs_rewinddir(struct nfs_context *nfs, struct nfsdir *nfsdir);
+
 
 /*
  * CLOSEDIR()
@@ -937,7 +1046,7 @@ EXTERN int nfs_chdir_async(struct nfs_context *nfs, const char *path, nfs_cb cb,
 /*
  * Sync chdir(<path>)
  * Function returns
- *      0 : The operation was successfull.
+ *      0 : The operation was successful.
  * -errno : The command failed.
  */
 EXTERN int nfs_chdir(struct nfs_context *nfs, const char *path);
@@ -955,7 +1064,7 @@ EXTERN int nfs_chdir(struct nfs_context *nfs, const char *path);
  * context is destroyed.
  *
  * Function returns
- *      0 : The operation was successfull and *cwd is filled in.
+ *      0 : The operation was successful and *cwd is filled in.
  * -errno : The command failed.
  */
 EXTERN void nfs_getcwd(struct nfs_context *nfs, const char **cwd);
@@ -981,7 +1090,7 @@ EXTERN int nfs_statvfs_async(struct nfs_context *nfs, const char *path, nfs_cb c
 /*
  * Sync statvfs(<dirname>)
  * Function returns
- *      0 : The operation was successfull.
+ *      0 : The operation was successful.
  * -errno : The command failed.
  */
 EXTERN int nfs_statvfs(struct nfs_context *nfs, const char *path, struct statvfs *svfs);
@@ -1008,11 +1117,21 @@ EXTERN int nfs_readlink_async(struct nfs_context *nfs, const char *path, nfs_cb
 /*
  * Sync readlink(<name>)
  * Function returns
- *      0 : The operation was successfull.
+ *      0 : The operation was successful.
  * -errno : The command failed.
  */
 EXTERN int nfs_readlink(struct nfs_context *nfs, const char *path, char *buf, int bufsize);
 
+/*
+ * Sync readlink2(<name>)
+ * Function returns
+ *       0 : The operation was successful.
+ *  -errno : The command failed.
+ * *bufptr : NULL if the command failed, otherwise the contents of the symlink.
+ *           The caller must free the buffer.
+ */
+EXTERN int nfs_readlink2(struct nfs_context *nfs, const char *path, char **bufptr);
+
 
 
 /*
@@ -1034,7 +1153,7 @@ EXTERN int nfs_chmod_async(struct nfs_context *nfs, const char *path, int mode,
 /*
  * Sync chmod(<name>)
  * Function returns
- *      0 : The operation was successfull.
+ *      0 : The operation was successful.
  * -errno : The command failed.
  */
 EXTERN int nfs_chmod(struct nfs_context *nfs, const char *path, int mode);
@@ -1062,7 +1181,7 @@ EXTERN int nfs_lchmod_async(struct nfs_context *nfs, const char *path, int mode,
  * symbolic link itself.
  *
  * Function returns
- *      0 : The operation was successfull.
+ *      0 : The operation was successful.
  * -errno : The command failed.
  */
 EXTERN int nfs_lchmod(struct nfs_context *nfs, const char *path, int mode);
@@ -1088,7 +1207,7 @@ EXTERN int nfs_fchmod_async(struct nfs_context *nfs, struct nfsfh *nfsfh, int mo
 /*
  * Sync fchmod(<handle>)
  * Function returns
- *      0 : The operation was successfull.
+ *      0 : The operation was successful.
  * -errno : The command failed.
  */
 EXTERN int nfs_fchmod(struct nfs_context *nfs, struct nfsfh *nfsfh, int mode);
@@ -1114,7 +1233,7 @@ EXTERN int nfs_chown_async(struct nfs_context *nfs, const char *path, int uid, i
 /*
  * Sync chown(<name>)
  * Function returns
- *      0 : The operation was successfull.
+ *      0 : The operation was successful.
  * -errno : The command failed.
  */
 EXTERN int nfs_chown(struct nfs_context *nfs, const char *path, int uid, int gid);
@@ -1142,7 +1261,7 @@ EXTERN int nfs_lchown_async(struct nfs_context *nfs, const char *path, int uid,
  * symbolic link itself.
  *
  * Function returns
- *      0 : The operation was successfull.
+ *      0 : The operation was successful.
  * -errno : The command failed.
  */
 EXTERN int nfs_lchown(struct nfs_context *nfs, const char *path, int uid, int gid);
@@ -1168,7 +1287,7 @@ EXTERN int nfs_fchown_async(struct nfs_context *nfs, struct nfsfh *nfsfh, int ui
 /*
  * Sync fchown(<handle>)
  * Function returns
- *      0 : The operation was successfull.
+ *      0 : The operation was successful.
  * -errno : The command failed.
  */
 EXTERN int nfs_fchown(struct nfs_context *nfs, struct nfsfh *nfsfh, int uid, int gid);
@@ -1195,7 +1314,7 @@ EXTERN int nfs_utimes_async(struct nfs_context *nfs, const char *path, struct ti
 /*
  * Sync utimes(<path>)
  * Function returns
- *      0 : The operation was successfull.
+ *      0 : The operation was successful.
  * -errno : The command failed.
  */
 EXTERN int nfs_utimes(struct nfs_context *nfs, const char *path, struct timeval *times);
@@ -1223,7 +1342,7 @@ EXTERN int nfs_lutimes_async(struct nfs_context *nfs, const char *path, struct t
  * symbolic link itself.
  *
  * Function returns
- *      0 : The operation was successfull.
+ *      0 : The operation was successful.
  * -errno : The command failed.
  */
 EXTERN int nfs_lutimes(struct nfs_context *nfs, const char *path, struct timeval *times);
@@ -1249,7 +1368,7 @@ EXTERN int nfs_utime_async(struct nfs_context *nfs, const char *path, struct uti
 /*
  * Sync utime(<path>)
  * Function returns
- *      0 : The operation was successfull.
+ *      0 : The operation was successful.
  * -errno : The command failed.
  */
 EXTERN int nfs_utime(struct nfs_context *nfs, const char *path, struct utimbuf *times);
@@ -1276,7 +1395,7 @@ EXTERN int nfs_access_async(struct nfs_context *nfs, const char *path, int mode,
 /*
  * Sync access(<path>)
  * Function returns
- *      0 : The operation was successfull.
+ *      0 : The operation was successful.
  * -errno : The command failed.
  */
 EXTERN int nfs_access(struct nfs_context *nfs, const char *path, int mode);
@@ -1333,7 +1452,7 @@ EXTERN int nfs_symlink_async(struct nfs_context *nfs, const char *oldpath, const
 /*
  * Sync symlink(<path>)
  * Function returns
- *      0 : The operation was successfull.
+ *      0 : The operation was successful.
  * -errno : The command failed.
  */
 EXTERN int nfs_symlink(struct nfs_context *nfs, const char *oldpath, const char *newpath);
@@ -1358,7 +1477,7 @@ EXTERN int nfs_rename_async(struct nfs_context *nfs, const char *oldpath, const
 /*
  * Sync rename(<oldpath>, <newpath>)
  * Function returns
- *      0 : The operation was successfull.
+ *      0 : The operation was successful.
  * -errno : The command failed.
  */
 EXTERN int nfs_rename(struct nfs_context *nfs, const char *oldpath, const char *newpath);
@@ -1384,7 +1503,7 @@ EXTERN int nfs_link_async(struct nfs_context *nfs, const char *oldpath, const ch
 /*
  * Sync link(<oldpath>, <newpath>)
  * Function returns
- *      0 : The operation was successfull.
+ *      0 : The operation was successful.
  * -errno : The command failed.
  */
 EXTERN int nfs_link(struct nfs_context *nfs, const char *oldpath, const char *newpath);
@@ -1445,6 +1564,28 @@ struct nfs_server_list {
 struct nfs_server_list *nfs_find_local_servers(void);
 void free_nfs_srvr_list(struct nfs_server_list *srv);
 
+/*
+ * sync nfs_set_timeout()
+ * This function sets the timeout used for nfs rpc calls.
+ *
+ * Function returns nothing.
+ *
+ * int milliseconds : timeout to be applied in milliseconds (-1 no timeout)
+ *                    timeouts must currently be set in whole seconds,
+ *                    i.e. units of 1000
+ */
+EXTERN void nfs_set_timeout(struct nfs_context *nfs, int milliseconds);
+
+/*
+ * sync nfs_get_timeout()
+ * This function gets the timeout used for nfs rpc calls.
+ *
+ * Function returns
+ *    -1 : No timeout applied
+ *   > 0 : Timeout in milliseconds
+ */
+EXTERN int nfs_get_timeout(struct nfs_context *nfs);
+
 #ifdef __cplusplus
 }
 #endif
